**************************************************
* Generate the plots related to data in Figure 1 *
**************************************************
clear all
set more off
use ../firm_level_data/working_data.dta

sort gvkey_n datadate
egen lshr_p99=pctile(lshr), p(99)
replace lshr=lshr_p99 if lshr>lshr_p99 & lshr<.
replace lshr=. if lshr<0

duplicates drop gvkey_n year, force
local cond_fig1 = "(sic_n>6999 | sic_n<6000) & year>=1992 & year<=2011 & fic_code<."
gen LEVB=(dltt+dlc)/at if dltt>=0 & dlc>=0 & at>0
replace LEVB=. if LEVB>1 | LEVB<0
replace cshoc=cshoc/1000000
gen mcap_mlev=prcc*cshoc
replace mcap_mlev=prcc*csho if mcap_mlev==. 
gen LEVM=(dltt+dlc)/(dltt+dlc+mcap_mlev) if dltt>=0 & dlc>=0 
replace LEVM=. if LEVM>1 | LEVM<0

keep if `cond_fig1'

by fic, sort: egen avg_lshr_fic=mean(lshr)
by fic, sort: egen avg_mlev_fic=mean(LEVM)
by fic, sort: egen avg_blev_fic=mean(LEVB)
by fic, sort: egen p50_lshr_fic=pctile(lshr),p(50)
by fic, sort: egen p50_mlev_fic=pctile(LEVM),p(50)
by fic, sort: egen p50_blev_fic=pctile(LEVB),p(50)

*** Top panels of Figure 1
preserve
keep if p50_lshr_fic<. & p50_mlev_fic<. & p50_blev_fic<.
duplicates drop p50_lshr_fic p50_mlev_fic p50_blev_fic, force
twoway (lfit p50_mlev_fic p50_lshr_fic, legend(off)) (scatter p50_mlev_fic p50_lshr_fic, legend(off) title("Data") ytitle("Country market leverage") xtitle("Country labor share"))
graph export ../firm_level_result/Fig1_country_median_LshrMLev.pdf, as(pdf) replace
twoway (lfit p50_blev_fic p50_lshr_fic, legend(off)) (scatter p50_blev_fic p50_lshr_fic, legend(off) title("Data") ytitle("Country book leverage") xtitle("Country labor share"))
graph export ../firm_level_result/Fig1_country_median_LshrBLev.pdf, as(pdf) replace
keep p50_blev_fic p50_mlev_fic p50_lshr_fic
order p50_blev_fic p50_mlev_fic p50_lshr_fic
export excel ../firm_level_result/Fig1_country_median_LshrFinLev.xlsx, replace
restore

*** Middle panels of Figure 1
preserve
by gvkey, sort: egen avg_lshr=mean(lshr-avg_lshr_fic) 
by gvkey, sort: egen avg_mlev=mean(LEVM-avg_mlev_fic)  
by gvkey, sort: egen avg_blev=mean(LEVB-avg_blev_fic) 

keep if avg_lshr<. & avg_mlev<. & avg_blev<.
duplicates drop gvkey avg_lshr avg_mlev avg_blev, force

forvalues i = 2(2)98{
    qui egen avg_lshr_p`i' = pctile(avg_lshr), p(`i')
}

gen rank_lshr=1
forvalues j=1(1)48{
    qui local jplus=`j'+1
	qui local jtile=2*`j'
	qui local jtileplus=2*`jplus'
    qui replace rank_lshr=`jplus' if avg_lshr>avg_lshr_p`jtile' & avg_lshr<=avg_lshr_p`jtileplus'
}
replace rank_lshr=50 if avg_lshr>avg_lshr_p98
by rank_lshr, sort: egen p50_lshr_port=pctile(avg_lshr), p(50)
by rank_lshr, sort: egen p50_mlev_port=pctile(avg_mlev), p(50)
by rank_lshr, sort: egen p50_blev_port=pctile(avg_blev), p(50)
keep if p50_lshr_port<. & p50_lshr_port<. & p50_lshr_port<. 
duplicates drop rank_lshr, force
twoway (lfit p50_mlev_port p50_lshr_port, legend(off)) (scatter p50_mlev_port p50_lshr_port, legend(off) title("Data") ytitle("Firm - Country market leverage") xtitle("Firm - Country labor share"))
graph export ../firm_level_result/Fig1_relative_LshrMLev_ctry_mean.pdf, as(pdf) replace
twoway (lfit p50_blev_port p50_lshr_port, legend(off)) (scatter p50_blev_port p50_lshr_port, legend(off) title("Data") ytitle("Firm - Country book leverage") xtitle("Firm - Country labor share"))
graph export ../firm_level_result/Fig1_relative_LshrBLev_ctry_mean.pdf, as(pdf) replace
keep rank_lshr p50_lshr_port p50_blev_port p50_mlev_port
order rank_lshr p50_lshr_port p50_blev_port p50_mlev_port
export excel ../firm_level_result/Fig1_relative_LshrFinLev_ctry_mean.xlsx, replace
restore


