**********************************************
* Beg: load dataset
**********************************************
clear all
set more off
use ../firm_level_data/working_data.dta

by fic, sort: egen dxlr_p1=pctile(d_xlr), p(1)
by fic, sort: egen dxlr_p99=pctile(d_xlr), p(99)
replace d_xlr=dxlr_p1 if d_xlr<dxlr_p1 
replace d_xlr=dxlr_p99 if d_xlr>dxlr_p99 & d_xlr<.

sort gvkey_n datadate
duplicates drop gvkey_n year, force
sort gvkey_n datadate
xtset gvkey_n year

**************** Table 2 regressions *************************
******** beg: regressions tab 2 EDF on dxlr *** 
*note EDF data in our sample available from 1992-2011
local cond_tab2 = "(sic_n>6999 | sic_n<6000) & year>=1992 & year<=2011 & fic_code<."
local firmvar_mcap = "sigma wc_ta re_ta ebit_ta blev SaleGr ni_ta ca_cl invest log_exr rsize log_rm log_mcap"
local depvar = "avg_edf_f1y"
eststo clear
eststo: qui xtfmb `depvar' d_xlr if `cond_tab2', lag(10)
eststo: qui xtfmb `depvar' d_xlr Ific_code* if `cond_tab2', lag(10)
eststo: qui xtfmb `depvar' d_xlr blev sigma Ific_code* if `cond_tab2', lag(10) 
eststo: qui xtfmb `depvar' d_xlr `firmvar_mcap' Ific_code* if `cond_tab2', lag(10) 
esttab using ../firm_level_result/AER_tab2_edf_dxlr.csv, replace b(%9.2fc) se(%9.2f) r2 label  nogaps longtable keep(d_xlr `firmvar_mcap') order(d_xlr  blev sigma `firmvar_mcap') nostar
* keep 3 digits in case 0.00 shows up
esttab using ../firm_level_result/AER_tab2_edf_dxlr_3d.csv, replace b(%9.3fc) se(%9.3f) r2 label  nogaps longtable keep(d_xlr `firmvar_mcap') order(d_xlr  blev sigma `firmvar_mcap') nostar

******** beg: regressions tab 2 DebtGr on dxlr *** 
local depvar = "DebtGr_f1y"
eststo clear
eststo: qui xtfmb `depvar' d_xlr if `cond_tab2', lag(10)
eststo: qui xtfmb `depvar' d_xlr Ific_code* if `cond_tab2', lag(10)
eststo: qui xtfmb `depvar' d_xlr blev sigma Ific_code* if `cond_tab2', lag(10) 
eststo: qui xtfmb `depvar' d_xlr `firmvar_mcap' Ific_code* if `cond_tab2', lag(10) 
esttab using ../firm_level_result/AER_tab2_DebtGr_dxlr.csv, replace b(%9.2fc) se(%9.2f) r2 label  nogaps longtable keep(d_xlr `firmvar_mcap') order(d_xlr  blev sigma `firmvar_mcap') nostar
esttab using ../firm_level_result/AER_tab2_DebtGr_dxlr_3d.csv, replace b(%9.3fc) se(%9.3f) r2 label  nogaps longtable keep(d_xlr `firmvar_mcap') order(d_xlr  blev sigma `firmvar_mcap') nostar

**************** Table 3 regressions conditional on rigidity mu *************************
* generate rigidity measure mu as the inverse of labor expense growth rate volatility
gen mu=1/dxlr_vol
by fic, sort: egen mu_p1=pctile(mu), p(1)
by fic, sort: egen mu_p99=pctile(mu), p(99)
replace mu=mu_p1 if mu<mu_p1 
replace mu=mu_p99 if mu>mu_p99 & mu<.
* create interaction term of dxlr with mu
gen rigid_dxlr=mu*d_xlr
******** beg: regressions tab 3 EDF and DebtGr on dxlr*mu *** 
local cond_tab3= "(sic_n>6999 | sic_n<6000) & year>=1992 & year<=2011 & fic_code<."
local firmvar_mcap = "sigma wc_ta re_ta ebit_ta blev SaleGr ni_ta ca_cl invest log_exr rsize log_rm log_mcap  "
eststo clear
eststo: qui xtfmb avg_edf_f1y d_xlr rigid_dxlr mu `firmvar_mcap' Ific_code* if `cond_tab3', lag(10) 
eststo: qui xtfmb DebtGr_f1y d_xlr rigid_dxlr mu `firmvar_mcap' Ific_code* if `cond_tab3', lag(10)
esttab using ../firm_level_result/AER_tab3_edf_DebtGr_dxlr.csv, replace b(%9.2fc) se(%9.2f) r2 label  nogaps longtable keep(d_xlr rigid_dxlr mu `firmvar_mcap') order(d_xlr rigid_dxlr mu blev sigma `firmvar_mcap') nostar
esttab using ../firm_level_result/AER_tab3_edf_DebtGr_dxlr_3d.csv, replace b(%9.3fc) se(%9.3f) r2 label  nogaps longtable keep(d_xlr rigid_dxlr mu `firmvar_mcap') order(d_xlr rigid_dxlr mu blev sigma `firmvar_mcap') nostar

**************** Table 4 regressions with CDS *************************
* note that CDS sample is much smaller and is from 2000 to 2013
joinby gvkey datadate using ../firm_level_data/ann_cds.dta, unm(m)
drop _merge
local cond_tab4 = "year>=2000 & year<=2013 & fic_code<. & d_xlr<. & mu<. & lshr<."
local firmvar_mcap = "sigma wc_ta re_ta ebit_ta blev SaleGr ni_ta ca_cl invest log_exr rsize log_rm log_mcap  "
eststo clear
eststo: qui xtfmb avg_cds5y_f1y d_xlr `firmvar_mcap' Ific_code* if `cond_tab4', lag(10)  
eststo: qui xtfmb avg_cds5y_f1y d_xlr rigid_dxlr mu `firmvar_mcap' Ific_code* if `cond_tab4', lag(10) 
eststo: qui xtfmb avg_cds1y_f1y d_xlr `firmvar_mcap' Ific_code* if `cond_tab4', lag(10)  
eststo: qui xtfmb avg_cds1y_f1y d_xlr rigid_dxlr mu `firmvar_mcap' Ific_code* if `cond_tab4', lag(10)   
esttab using ../firm_level_result/AER_tab4_cds_dxlr.csv, replace b(%9.2fc) se(%9.2f) r2 label  nogaps longtable keep(d_xlr rigid_dxlr mu `firmvar_mcap') order(d_xlr rigid_dxlr mu blev sigma `firmvar_mcap') nostar
esttab using ../firm_level_result/AER_tab4_cds_dxlr_3d.csv, replace b(%9.3fc) se(%9.3f) r2 label  nogaps longtable keep(d_xlr rigid_dxlr mu `firmvar_mcap') order(d_xlr rigid_dxlr mu blev sigma `firmvar_mcap') nostar


