**********************************************
* Beg: Merge datasets
**********************************************
clear all
set more off
use ../firm_level_data/working_data.dta

sort gvkey_n datadate
egen lshr_p99=pctile(lshr), p(99)
replace lshr=lshr_p99 if lshr>lshr_p99 & lshr<.
replace lshr=. if lshr<0

duplicates drop gvkey_n year, force
sort gvkey_n datadate
xtset gvkey_n year

**************** Table 2 regressions *************************
*note EDF data in our sample available from 1992-2011
local firmvar_mcap = "sigma wc_ta re_ta ebit_ta blev SaleGr ni_ta ca_cl invest log_exr rsize log_rm log_mcap"
******** beg: regressions tab 2 EDF on lshr *** 
local cond_tab2 = "(sic_n>6999 | sic_n<6000) & year>=1992 & year<=2011"
local depvar = "avg_edf_f1y"
eststo clear
eststo: qui xtfmb `depvar' lshr if `cond_tab2' & fic_code<., lag(10)
eststo: qui xtfmb `depvar' lshr Ific_code* if `cond_tab2' & fic_code<., lag(10)
eststo: qui xtfmb `depvar' lshr blev sigma Ific_code* if `cond_tab2' & fic_code<., lag(10) 
eststo: qui xtfmb `depvar' lshr `firmvar_mcap' Ific_code* if `cond_tab2' & fic_code<., lag(10) 
esttab using ../firm_level_result/AER_tab2_edf_lshr.csv, replace b(%9.2fc) se(%9.2f) r2 label  nogaps longtable keep(lshr `firmvar_mcap') order(lshr  blev sigma `firmvar_mcap') nostar
* keep 3 digits in case 0.00 shows up
esttab using ../firm_level_result/AER_tab2_edf_lshr_3d.csv, replace b(%9.3fc) se(%9.3f) r2 label  nogaps longtable keep(lshr `firmvar_mcap') order(lshr  blev sigma `firmvar_mcap') nostar
******** beg: regressions tab 2 DebtGr on lshr *** 
local depvar = "DebtGr_f1y"
eststo clear
eststo: qui xtfmb `depvar' lshr if `cond_tab2' & fic_code<., lag(10)
eststo: qui xtfmb `depvar' lshr Ific_code* if `cond_tab2' & fic_code<., lag(10)
eststo: qui xtfmb `depvar' lshr blev sigma Ific_code* if `cond_tab2' & fic_code<., lag(10) 
eststo: qui xtfmb `depvar' lshr `firmvar_mcap' Ific_code* if `cond_tab2' & fic_code<., lag(10) 
esttab using ../firm_level_result/AER_tab2_DebtGr_lshr.csv, replace b(%9.2fc) se(%9.2f) r2 label  nogaps longtable keep(lshr `firmvar_mcap') order(lshr  blev sigma `firmvar_mcap') nostar
esttab using ../firm_level_result/AER_tab2_DebtGr_lshr_3d.csv, replace b(%9.3fc) se(%9.3f) r2 label  nogaps longtable keep(lshr `firmvar_mcap') order(lshr  blev sigma `firmvar_mcap') nostar


**************** Table 3 regressions conditional on rigidity mu *************************
* generate rigidity measure mu as the inverse of labor expense growth rate volatility
gen mu=1/dxlr_vol
by fic, sort: egen mu_p1=pctile(mu), p(1)
by fic, sort: egen mu_p99=pctile(mu), p(99)
replace mu=mu_p1 if mu<mu_p1 
replace mu=mu_p99 if mu>mu_p99 & mu<.
gen rigid_lshr=mu*lshr
******** beg: regressions tab 3 EDF and DebtGr on lshr*mu *** 
local cond_tab3 = "(sic_n>6999 | sic_n<6000) & year>=1992 & year<=2011"
local firmvar_mcap = "sigma wc_ta re_ta ebit_ta blev SaleGr ni_ta ca_cl invest log_exr rsize log_rm log_mcap"
eststo clear
eststo: qui xtfmb avg_edf_f1y lshr rigid_lshr mu `firmvar_mcap' Ific_code* if `cond_tab3' & fic_code<., lag(10) 
eststo: qui xtfmb DebtGr_f1y lshr rigid_lshr mu `firmvar_mcap' Ific_code* if `cond_tab3' & fic_code<., lag(10) 
esttab using ../firm_level_result/AER_tab3_edf_DebtGr_lshr.csv, replace b(%9.2fc) se(%9.2f) r2 label  nogaps longtable keep(lshr rigid_lshr mu `firmvar_mcap') order(lshr rigid_lshr mu blev sigma `firmvar_mcap') nostar
esttab using ../firm_level_result/AER_tab3_edf_DebtGr_lshr_3d.csv, replace b(%9.3fc) se(%9.3f) r2 label  nogaps longtable keep(lshr rigid_lshr mu `firmvar_mcap') order(lshr rigid_lshr mu blev sigma `firmvar_mcap') nostar

**************** Table 4 regressions with CDS *************************
* note that CDS sample is much smaller and is from 2000 to 2013
joinby gvkey datadate using ../firm_level_data/ann_cds.dta, unm(m)
drop _merge
local cond_tab4 = "year>=2000 & year<=2013 & fic_code<. & d_xlr<. & mu<. & lshr<."
local firmvar_mcap = "sigma wc_ta re_ta ebit_ta blev SaleGr ni_ta ca_cl invest log_exr rsize log_rm log_mcap"
eststo clear
eststo: qui xtfmb avg_cds5y_f1y lshr `firmvar_mcap' Ific_code* if `cond_tab4' & fic_code<., lag(10) 
eststo: qui xtfmb avg_cds5y_f1y lshr rigid_lshr mu `firmvar_mcap' Ific_code* if `cond_tab4' & fic_code<., lag(10)
eststo: qui xtfmb avg_cds1y_f1y lshr `firmvar_mcap' Ific_code* if `cond_tab4' & fic_code<., lag(10) 
eststo: qui xtfmb avg_cds1y_f1y lshr rigid_lshr mu `firmvar_mcap' Ific_code* if `cond_tab4' & fic_code<., lag(10)  
esttab using ../firm_level_result/AER_tab4_cds_lshr.csv, replace b(%9.2fc) se(%9.2f) r2 label  nogaps longtable keep(lshr rigid_lshr mu `firmvar_mcap') order(lshr rigid_lshr mu blev sigma `firmvar_mcap') nostar
esttab using ../firm_level_result/AER_tab4_cds_lshr_3d.csv, replace b(%9.3fc) se(%9.3f) r2 label  nogaps longtable keep(lshr rigid_lshr mu `firmvar_mcap') order(lshr rigid_lshr mu blev sigma `firmvar_mcap') nostar

**************** Table 5 regressions of FinLev on LS *************************
gen LEVB=(dltt+dlc)/at if dltt>=0 & dlc>=0 & at>0
replace LEVB=. if LEVB>1 | LEVB<0
replace cshoc=cshoc/1000000
gen mcap_mlev=prcc*cshoc
replace mcap_mlev=prcc*csho if mcap_mlev==. 
gen LEVM=(dltt+dlc)/(dltt+dlc+mcap_mlev) if dltt>=0 & dlc>=0 
replace LEVM=. if LEVM>1 | LEVM<0
preserve
local cond_tab5 = "(sic_n>6999 | sic_n<6000) & year>=1992 & year<=2011 & fic_code<."
keep if `cond_tab5'
by gvkey, sort: egen avg_LS=mean(lshr) if `cond_tab5'
by gvkey, sort: egen avg_LEVM=mean(LEVM) if `cond_tab5'
by gvkey, sort: egen avg_LEVB=mean(LEVB) if `cond_tab5'
by gvkey, sort: egen avg_sigma=mean(sigma) if `cond_tab5'
by gvkey, sort: egen avg_wc_ta=mean(wc_ta) if `cond_tab5'
by gvkey, sort: egen avg_re_ta=mean(re_ta) if `cond_tab5'
by gvkey, sort: egen avg_ebit_ta=mean(ebit_ta) if `cond_tab5'
by gvkey, sort: egen avg_SaleGr=mean(SaleGr) if `cond_tab5'
by gvkey, sort: egen avg_ni_ta=mean(ni_ta) if `cond_tab5'
by gvkey, sort: egen avg_ca_cl=mean(ca_cl) if `cond_tab5'
by gvkey, sort: egen avg_invest=mean(invest) if `cond_tab5'
by gvkey, sort: egen avg_log_exr=mean(log_exr) if `cond_tab5'
by gvkey, sort: egen avg_rsize=mean(rsize) if `cond_tab5'
by gvkey, sort: egen avg_log_rm=mean(log_rm) if `cond_tab5'
by gvkey, sort: egen avg_log_mcap=mean(log_mcap) if `cond_tab5'
by fic, sort: egen avg_LS_fic=mean(lshr)
by fic, sort: egen avg_LEVM_fic=mean(LEVM)
by fic, sort: egen avg_LEVB_fic=mean(LEVB)
keep if avg_LS<. & avg_LEVM<. & avg_LEVB<.
duplicates drop gvkey avg_LS avg_LEVM avg_LEVB, force
local avg_firmvar_mcap = "avg_sigma avg_wc_ta avg_re_ta avg_ebit_ta avg_SaleGr avg_ni_ta avg_ca_cl avg_invest avg_log_exr avg_rsize avg_log_rm avg_log_mcap"
eststo clear
eststo: reg avg_LEVM avg_LS  if  fic_code<. & avg_LEVB<.
eststo: reg avg_LEVM avg_LS Ific_code* if  fic_code<. & avg_LEVB<.
eststo: reg avg_LEVM avg_LS `avg_firmvar_mcap' Ific_code* if  fic_code<. & avg_LEVB<.
eststo: reg avg_LEVB avg_LS  if  fic_code<. & avg_LEVM<.
eststo: reg avg_LEVB avg_LS Ific_code* if  fic_code<. & avg_LEVM<.
eststo: reg avg_LEVB avg_LS `avg_firmvar_mcap' Ific_code* if  fic_code<. & avg_LEVM<.
esttab using ../firm_level_result/AER_tab5_FinLev_LS_avg.csv, replace b(%9.3fc) se(%9.2f) r2 label  nogaps longtable keep(avg_LS `avg_firmvar_mcap') order(avg_LS `avg_firmvar_mcap') nostar
esttab using ../firm_level_result/AER_tab5_FinLev_LS_avg_3d.csv, replace b(%9.3fc) se(%9.3f) r2 label  nogaps longtable keep(avg_LS `avg_firmvar_mcap') order(avg_LS `avg_firmvar_mcap') nostar
restore

************* Table 8 regressions of real outcome on leverage and credit risk *************************
sort gvkey_n year
gen IK=capx/ppent[_n-1] if ppent[_n-1]>=0 & gvkey_n==gvkey_n[_n-1] & (fyear==fyear[_n-1]+1)
replace IK=. if IK<-0.1 | IK>0.7

egen HN_p1=pctile(HN), p(1)
egen HN_p99=pctile(HN), p(99)
replace HN=. if HN<HN_p1
replace HN=. if HN>HN_p99

egen Sigma_p1=pctile(sigma), p(1)
egen Sigma_p99=pctile(sigma), p(99)
replace sigma=. if sigma<Sigma_p1
replace sigma=. if sigma>Sigma_p99

sort gvkey_n year
gen IK_f1y=IK[_n+1] if gvkey_n==gvkey_n[_n+1] 
gen HN_f1y=HN[_n+1] if gvkey_n==gvkey_n[_n+1]
gen Sigma_f1y=sigma[_n+1] if gvkey_n==gvkey_n[_n+1]

local cond_tab8 = "(sic_n>6999 | sic_n<6000) & fic_code<. & year>=1992 & year<=2011"
eststo clear
eststo: qui xtfmb HN_f1y lshr blev  if `cond_tab8' , lag(10)
eststo: qui xtfmb HN_f1y avg_edf  if `cond_tab8' , lag(10)
eststo: qui xtfmb IK_f1y lshr blev  if `cond_tab8' , lag(10)
eststo: qui xtfmb IK_f1y avg_edf  if `cond_tab8' , lag(10)
eststo: qui xtfmb Sigma_f1y lshr blev  if `cond_tab8' , lag(10)
eststo: qui xtfmb Sigma_f1y avg_edf  if `cond_tab8' , lag(10)
esttab using ../firm_level_result/AER_tab8_firm_level.csv, replace b(%9.3fc) se(%9.2f) r2 label keep(lshr blev avg_edf) nogaps longtable  nostar
esttab using ../firm_level_result/AER_tab8_firm_level_3d.csv, replace b(%9.3fc) se(%9.3f) r2 label keep(lshr blev avg_edf) nogaps longtable  nostar


**************** Table 9 regressions of EDF and DebtGr on Total Leverage *************************
gen IS=xint/(xlr+ebitda)
replace IS=. if xlr<0 | xint<0
by fic, sort: egen IS_p1=pctile(IS), p(1)
by fic, sort: egen IS_p99=pctile(IS), p(99)
replace IS=IS_p1 if IS<IS_p1 
replace IS=IS_p99 if IS>IS_p99 & IS<.
gen TotalLev_flow=IS+lshr

local cond_tab9 = "(sic_n>6999 | sic_n<6000) & fic_code<. & year>=1992 & year<=2011"
eststo clear
eststo: qui xtfmb avg_edf_f1y lshr Ific_code* if `cond_tab9' , lag(10)
eststo: qui xtfmb avg_edf_f1y IS  Ific_code* if `cond_tab9' , lag(10)
eststo: qui xtfmb avg_edf_f1y lshr IS  Ific_code* if `cond_tab9' , lag(10)
eststo: qui xtfmb avg_edf_f1y TotalLev_flow Ific_code* if `cond_tab9' , lag(10)
eststo: qui xtfmb DebtGr_f1y lshr Ific_code* if `cond_tab9' , lag(10)
eststo: qui xtfmb DebtGr_f1y IS Ific_code* if `cond_tab9' , lag(10)
eststo: qui xtfmb DebtGr_f1y lshr IS Ific_code* if `cond_tab9' , lag(10)
eststo: qui xtfmb DebtGr_f1y TotalLev_flow Ific_code* if `cond_tab9' , lag(10)
esttab using ../firm_level_result/AER_tab9_firm_level.csv, replace b(%9.3fc) se(%9.2f) r2 label keep(lshr IS TotalLev_flow) order(lshr IS TotalLev_flow) nogaps longtable  nostar
esttab using ../firm_level_result/AER_tab9_firm_level_3d.csv, replace b(%9.3fc) se(%9.3f) r2 label keep(lshr IS TotalLev_flow) order(lshr IS TotalLev_flow) nogaps longtable  nostar


************** Table 10 Panel C, correlation numbers at the firm level ******************************
local cond_tab10 = "(sic_n>6999 | sic_n<6000) & fic_code<. & year>=1992 & year<=2011"
reg d_xlr SaleGr if `cond_tab10'
predict dxlr_res, res
reg lshr SaleGr if `cond_tab10'
predict LS_res, res
eststo clear
estpost correlate dxlr_res avg_edf_f1y if `cond_tab10', matrix
esttab using ../firm_level_result/AER_tab10_firm_level_correlations.csv, b(%8.2f) not unstack compress noobs replace nostar
eststo clear
estpost correlate LS_res avg_edf_f1y if `cond_tab10', matrix
esttab using ../firm_level_result/AER_tab10_firm_level_correlations.csv, b(%8.2f) not unstack compress noobs append nostar
eststo clear
estpost correlate dxlr_res DebtGr_f1y if `cond_tab10', matrix
esttab using ../firm_level_result/AER_tab10_firm_level_correlations.csv, b(%8.2f) not unstack compress noobs append nostar
estpost correlate LS_res DebtGr_f1y if `cond_tab10', matrix
esttab using ../firm_level_result/AER_tab10_firm_level_correlations.csv, b(%8.2f) not unstack compress noobs append nostar
