**********************************************
* Begin: Read working dataset
**********************************************
clear all
set more off
use ../firm_level_data/working_data.dta

sort gvkey_n datadate
egen lshr_p99=pctile(lshr), p(99)
replace lshr=lshr_p99 if lshr>lshr_p99 & lshr<.
replace lshr=. if lshr<0

by fic, sort: egen dxlr_p1=pctile(d_xlr), p(1)
by fic, sort: egen dxlr_p99=pctile(d_xlr), p(99)
replace d_xlr=dxlr_p1 if d_xlr<dxlr_p1 
replace d_xlr=dxlr_p99 if d_xlr>dxlr_p99 & d_xlr<.

sort gvkey_n datadate
duplicates drop gvkey_n year, force

***** generate the key variables for the regressions in online appendix ************
gen mu=1/dxlr_vol
by fic, sort: egen mu_p1=pctile(mu), p(1)
by fic, sort: egen mu_p99=pctile(mu), p(99)
replace mu=mu_p1 if mu<mu_p1 
replace mu=mu_p99 if mu>mu_p99 & mu<.
* create interaction term between labor leverage proxy (d_xlr, lshr) and rigidity
gen rigid_dxlr=mu*d_xlr
gen rigid_lshr=mu*lshr

by fic, sort: egen HN_p1=pctile(HN), p(1)
by fic, sort: egen HN_p99=pctile(HN), p(99)
replace HN=HN_p1 if HN<HN_p1 
replace HN=HN_p99 if HN>HN_p99 & HN<.

by fic, sort: egen WageGr_p1=pctile(WageGr), p(1)
by fic, sort: egen WageGr_p99=pctile(WageGr), p(99)
replace WageGr=WageGr_p1 if WageGr<WageGr_p1 
replace WageGr=WageGr_p99 if WageGr>WageGr_p99 & WageGr<.

replace cshoc=cshoc/1000000
gen mcap_mlev=prcc*cshoc
replace mcap_mlev=prcc*csho if mcap_mlev==. 
gen mlev=(dltt+dlc)/(dltt+dlc+mcap_mlev) if dltt>=0 & dlc>=0 
replace mlev=. if mlev>1 | mlev<0

***** end of generating the variables ************

sort gvkey_n datadate
xtset gvkey_n year

**************** Online Table A.11 EDF on dXLR and LS, control for book leverage *************************
local cond = "(sic_n>6999 | sic_n<6000) & year>=1992 & year<=2011 & fic_code<."
local firmvar_mcap_blev = "sigma wc_ta re_ta ebit_ta blev SaleGr ni_ta ca_cl invest log_exr rsize log_rm log_mcap"
local display_var="sigma wc_ta re_ta ebit_ta blev SaleGr ni_ta ca_cl invest log_exr rsize log_rm log_mcap"
local depvar = "avg_edf_f1y"
eststo clear
* control for book leverage
eststo: qui xtfmb `depvar' d_xlr `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb `depvar' d_xlr rigid_dxlr mu `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb `depvar' lshr `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb `depvar' lshr rigid_lshr mu `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
local depvar = "DebtGr_f1y"
eststo: qui xtfmb `depvar' d_xlr `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb `depvar' d_xlr rigid_dxlr mu `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb `depvar' lshr `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb `depvar' lshr rigid_lshr mu `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
esttab using ../firm_level_result/OA_A11_EDF_DebtGr.csv, replace b(%9.3fc) se(%9.3f) r2 label  nogaps longtable keep(d_xlr lshr rigid_dxlr rigid_lshr mu `display_var') order(d_xlr lshr rigid_dxlr rigid_lshr mu blev sigma `firmvar_mcap_blev') nostar

**************** Online Table A.12 EDF on dXLR and LS, control for market leverage *************************
local cond = "(sic_n>6999 | sic_n<6000) & year>=1992 & year<=2011 & fic_code<."
local firmvar_mcap_mlev = "sigma wc_ta re_ta ebit_ta mlev SaleGr ni_ta ca_cl invest log_exr rsize log_rm log_mcap"
local display_var="sigma wc_ta re_ta ebit_ta mlev SaleGr ni_ta ca_cl invest log_exr rsize log_rm log_mcap"
local depvar = "avg_edf_f1y"
eststo clear
* control for market leverage
eststo: qui xtfmb `depvar' d_xlr `firmvar_mcap_mlev' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb `depvar' d_xlr rigid_dxlr mu `firmvar_mcap_mlev' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb `depvar' lshr `firmvar_mcap_mlev' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb `depvar' lshr rigid_lshr mu `firmvar_mcap_mlev' Ific_code* if `cond', lag(10) 
local depvar = "DebtGr_f1y"
eststo: qui xtfmb `depvar' d_xlr `firmvar_mcap_mlev' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb `depvar' d_xlr rigid_dxlr mu `firmvar_mcap_mlev' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb `depvar' lshr `firmvar_mcap_mlev' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb `depvar' lshr rigid_lshr mu `firmvar_mcap_mlev' Ific_code* if `cond', lag(10) 
esttab using ../firm_level_result/OA_A12_EDF_DebtGr.csv, replace b(%9.3fc) se(%9.3f) r2 label  nogaps longtable keep(d_xlr lshr rigid_dxlr rigid_lshr mu `display_var') order(d_xlr lshr rigid_dxlr rigid_lshr mu mlev sigma `firmvar_mcap_mlev') nostar


**************** Online Table A.13 DebtGr, EDF on dXLR and LS, controll for HN *************************
local cond = "(sic_n>6999 | sic_n<6000) & year>=1992 & year<=2011 & fic_code<."
local firmvar_mcap_blev = "sigma wc_ta re_ta ebit_ta blev SaleGr ni_ta ca_cl invest log_exr rsize log_rm log_mcap"
local display_var="sigma wc_ta re_ta ebit_ta blev SaleGr ni_ta ca_cl invest log_exr rsize log_rm log_mcap"
local depvar = "avg_edf_f1y"
eststo clear
eststo: qui xtfmb `depvar' d_xlr HN `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb `depvar' d_xlr HN rigid_dxlr mu `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb `depvar' lshr HN `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb `depvar' lshr HN rigid_lshr mu `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
local depvar = "DebtGr_f1y"
eststo: qui xtfmb `depvar' d_xlr HN `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb `depvar' d_xlr HN rigid_dxlr mu `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb `depvar' lshr HN `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb `depvar' lshr HN rigid_lshr mu `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
esttab using ../firm_level_result/OA_A13_EDF_DebtGr_cHN.csv, replace b(%9.3fc) se(%9.3f) r2 label  nogaps longtable keep(d_xlr lshr rigid_dxlr rigid_lshr mu HN `display_var') order(d_xlr lshr rigid_dxlr rigid_lshr mu HN blev sigma `firmvar_mcap_blev') nostar


****************** Create alternative rigidity measure based on autocorrelation of dXLR ***************************
sort gvkey datadate
gen lag_dxlr=d_xlr[_n-1] if gvkey==gvkey[_n-1]
gen indAC=1 if d_xlr<. & lag_dxlr<.
gen temp_term1=lag_dxlr*d_xlr
by gvkey, sort: egen temp_term2=mean(temp_term1)
by gvkey, sort: egen temp_term3=mean(indAC*lag_dxlr)
by gvkey, sort: egen temp_term4=mean(indAC*d_xlr)
by gvkey, sort: egen temp_term5=sd(indAC*lag_dxlr)
by gvkey, sort: egen temp_term6=sd(indAC*d_xlr)
gen AC_dxlr=(temp_term2-temp_term3*temp_term4)/(temp_term5*temp_term6)
by gvkey, sort: egen nobs_AC=sum(indAC)
egen AC_dxlr_p1=pctile(AC_dxlr), p(1)
egen AC_dxlr_p99=pctile(AC_dxlr), p(99)
replace AC_dxlr=AC_dxlr_p1 if AC_dxlr<AC_dxlr_p1 
replace AC_dxlr=AC_dxlr_p99 if AC_dxlr>AC_dxlr_p99 & AC_dxlr<.

gen rigidAC_dxlr=AC_dxlr*d_xlr
gen rigidAC_lshr=AC_dxlr*lshr
egen ACdxlr_p75=pctile(AC_dxlr),p(75)
gen high_AC=1 if AC_dxlr>ACdxlr_p75 & AC_dxlr<.
replace high_AC=0 if AC_dxlr<=ACdxlr_p75

sort gvkey_n datadate
xtset gvkey_n year
**************** Online Table A.14 DebtGr, EDF and dXLR, alternative rigidity measure, controll for HN *************************
local cond = "(sic_n>6999 | sic_n<6000) & year>=1992 & year<=2011 & fic_code<."
local firmvar_mcap_blev = "sigma wc_ta re_ta ebit_ta blev SaleGr ni_ta ca_cl invest log_exr rsize log_rm log_mcap"
local display_var="sigma wc_ta re_ta ebit_ta blev SaleGr ni_ta ca_cl invest log_exr rsize log_rm log_mcap"
eststo clear
eststo: qui xtfmb avg_edf_f1y d_xlr HN rigidAC_dxlr AC_dxlr `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb avg_edf_f1y lshr HN rigidAC_lshr AC_dxlr `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb DebtGr_f1y d_xlr HN rigidAC_dxlr AC_dxlr `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb DebtGr_f1y lshr HN rigidAC_lshr AC_dxlr `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
esttab using ../firm_level_result/OA_A14_EDF_DebtGr_rigidAC_cHN.csv, replace b(%9.3fc) se(%9.3f) r2 label  nogaps longtable keep(d_xlr lshr rigidAC_dxlr rigidAC_lshr AC_dxlr HN `display_var') order(d_xlr lshr rigidAC_dxlr rigidAC_lshr AC_dxlr HN blev sigma `firmvar_mcap_blev') nostar

**************** Online Table A.15 DebtGr, EDF and WageGr, controll for HN *************************
gen rigid_wagegr=mu*WageGr
local cond = "(sic_n>6999 | sic_n<6000) & year>=1992 & year<=2011 & fic_code<."
local firmvar_mcap_blev = "sigma wc_ta re_ta ebit_ta blev SaleGr ni_ta ca_cl invest log_exr rsize log_rm log_mcap"
local display_var="sigma wc_ta re_ta ebit_ta blev SaleGr ni_ta ca_cl invest log_exr rsize log_rm log_mcap"
local depvar = "avg_edf_f1y"
eststo clear
eststo: qui xtfmb `depvar' WageGr HN `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb `depvar' WageGr HN rigid_wagegr mu `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
local depvar = "DebtGr_f1y"
eststo: qui xtfmb `depvar' WageGr HN `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb `depvar' WageGr HN rigid_wagegr mu `firmvar_mcap_blev' Ific_code* if `cond', lag(10) 
esttab using ../firm_level_result/OA_A15_EDF_DebtGr_WageGr_cHN.csv, replace b(%9.3fc) se(%9.3f) r2 label  nogaps longtable keep(WageGr rigid_wagegr mu HN `display_var') order(WageGr rigid_wagegr mu HN blev sigma `firmvar_mcap_blev') nostar


**************** Online Table A.17 regressions of FinLev[t+1] on LS[t] *************************
gen LEVB=(dltt+dlc)/at if dltt>=0 & dlc>=0 & at>0
replace LEVB=. if LEVB>1 | LEVB<0
gen LEVM=(dltt+dlc)/(dltt+dlc+mcap_mlev) if dltt>=0 & dlc>=0 
replace LEVM=. if LEVM>1 | LEVM<0
sort gvkey datadate
gen LEVB_f1y=LEVB[_n+1] if gvkey==gvkey[_n+1] & (fyear==fyear[_n+1]-1)
gen LEVM_f1y=LEVM[_n+1] if gvkey==gvkey[_n+1] & (fyear==fyear[_n+1]-1)
local cond = "(sic_n>6999 | sic_n<6000) & year>=1992 & year<=2011 & LEVM_f1y<. & LEVB_f1y<. & fic_code<."
local firmvar_mcap_LEVB = "sigma wc_ta re_ta ebit_ta LEVB SaleGr ni_ta ca_cl invest log_exr rsize log_rm log_mcap "
local firmvar_mcap_LEVM = "sigma wc_ta re_ta ebit_ta LEVM SaleGr ni_ta ca_cl invest log_exr rsize log_rm log_mcap "
eststo clear
eststo: qui xtfmb LEVM_f1y lshr  if `cond', lag(10) 
eststo: qui xtfmb LEVM_f1y lshr Ific_code* if `cond', lag(10) 
eststo: qui xtfmb LEVM_f1y lshr LEVM Ific_code* if `cond', lag(10) 
eststo: qui xtfmb LEVM_f1y lshr `firmvar_mcap_LEVM' Ific_code* if `cond', lag(10) 
eststo: qui xtfmb LEVB_f1y lshr  if `cond', lag(10) 
eststo: qui xtfmb LEVB_f1y lshr Ific_code* if `cond', lag(10) 
eststo: qui xtfmb LEVB_f1y lshr LEVB Ific_code* if `cond', lag(10) 
eststo: qui xtfmb LEVB_f1y lshr `firmvar_mcap_LEVB' Ific_code* if `cond', lag(10)  
esttab using ../firm_level_result/OA_A17_FinLev_LS_3d.csv, replace b(%9.3fc) se(%9.3f) r2 label  nogaps longtable keep(lshr LEVB LEVM sigma `firmvar_mcap_LEVB') order(lshr LEVM LEVB sigma `firmvar_mcap_LEVB') nostar





