**********************************************
* Begin: Merge datasets
**********************************************
clear all
set more off
use ../firm_level_data/def_data.dta
joinby gvkey datadate using ../firm_level_data/cg_cna_sale.dta, unm(m)
tab _merge
drop _merge
joinby gvkey datadate using ../firm_level_data/cg_cna_defvar.dta, unm(m)
tab _merge
drop _merge
joinby fic using ../firm_level_data/FIC_code, unm(m)
tab _merge
drop _merge
joinby gvkey datadate using ../firm_level_data/fx_acct.dta, unm(m)
tab _merge
drop _merge
joinby gvkey datadate using ../firm_level_data/cgcna_update.dta, unm(m)
tab _merge
drop _merge
joinby gvkey datadate using ../firm_level_data/cg_cna_ebitda.dta, unm(m)
tab _merge
drop _merge
joinby gvkey datadate using ../firm_level_data/cg_cna_xint.dta, unm(m)
tab _merge
drop _merge
joinby gvkey datadate using ../firm_level_data/def_data_201503.dta, unm(m)
tab _merge
drop _merge
/**********************************************
* End: Merge datasets
**********************************************/

**********************************************
* Beg: Create varibles for regressions
**********************************************
gen year=year(datadate)
sort gvkey datadate
gen lshr=xlr/(xlr+ebitda) if xlr>=0
gen Debt=(dltt+dlc) if dltt>=0 & dlc>=0 
gen LaborExpense=xlr if xlr>=0
gen d_xlr=2*(LaborExpense-LaborExpense[_n-1])/(LaborExpense+LaborExpense[_n-1]) if gvkey==gvkey[_n-1] & (fyear==fyear[_n-1]+1)
gen DebtGr=2*(Debt-Debt[_n-1])/(Debt+Debt[_n-1]) if gvkey==gvkey[_n-1] & (fyear==fyear[_n-1]+1) & Debt>0 & Debt[_n-1]>0
gen avg_edf_f1y=avg_edf[_n+1] if gvkey==gvkey[_n+1] & (fyear==fyear[_n+1]-1)
gen DebtGr_f1y=DebtGr[_n+1] if gvkey==gvkey[_n+1] & (fyear==fyear[_n+1]-1)
sort gvkey_n datadate

egen lshr_p99=pctile(lshr), p(99)
replace lshr=lshr_p99 if lshr>lshr_p99 & lshr<.
replace lshr=. if lshr<0

by fic, sort: egen dxlr_p1=pctile(d_xlr), p(1)
by fic, sort: egen dxlr_p99=pctile(d_xlr), p(99)
replace d_xlr=dxlr_p1 if d_xlr<dxlr_p1 
replace d_xlr=dxlr_p99 if d_xlr>dxlr_p99 & d_xlr<.

sort gvkey_n datadate
duplicates drop gvkey_n year, force
keep d_xlr lshr avg_edf_f1y DebtGr_f1y gvkey_n datadate
order d_xlr lshr avg_edf_f1y DebtGr_f1y gvkey_n datadate
saveold ../firm_level_data/xlr_edf_debt_matlab.dta, replace v(12)
