**********************************************
* Beg: Merge datasets
**********************************************
clear all
set more off
use ../firm_level_data/def_data.dta
joinby gvkey datadate using ../firm_level_data/cg_cna_sale.dta, unm(m)
tab _merge
drop _merge
joinby gvkey datadate using ../firm_level_data/cg_cna_defvar.dta, unm(m)
tab _merge
drop _merge
joinby fic using ../firm_level_data/FIC_code, unm(m)
tab _merge
drop _merge
joinby gvkey datadate using ../firm_level_data/fx_acct.dta, unm(m)
tab _merge
drop _merge
joinby gvkey datadate using ../firm_level_data/cgcna_update.dta, unm(m)
tab _merge
drop _merge
joinby gvkey datadate using ../firm_level_data/cg_cna_ebitda.dta, unm(m)
tab _merge
drop _merge
joinby gvkey datadate using ../firm_level_data/cg_cna_xint.dta, unm(m)
tab _merge
drop _merge
joinby gvkey datadate using ../firm_level_data/def_data_201503.dta, unm(m)
tab _merge
drop _merge
gen year=year(datadate)
gen sic_n=real(sic)

/**********************************************
* End: Merge datasets
**********************************************/

*************** Online Table A8 No of Obs with non-missing XLR and EDF *********************
* generate total number of observations for all countries 
preserve 
local conds = "(sic_n>6999 | sic_n<6000) & year>=1992 & year<=2011 & fic_code<."
sort gvkey_n datadate
duplicates drop gvkey_n year, force
egen n_obs_total=count(fic_code) if `conds'
egen n_obs_xlr=count(fic_code) if `conds' & xlr<.
egen n_obs_edf=count(fic_code) if `conds' & avg_edf<.
egen n_obs_xlr_edf=count(fic_code) if `conds' & xlr<. & avg_edf<.
gen min_year=.
gen max_year=.
keep if n_obs_total<. & n_obs_xlr<. & n_obs_edf<. & n_obs_xlr_edf<.
duplicates drop n_obs_total, force
replace fic_name="Total"
keep fic fic_name fic_code region region_code n_obs_total min_year max_year n_obs_xlr n_obs_edf n_obs_xlr_edf
replace fic=""
replace region=""
replace fic_code=.
replace region_code=.
save ../firm_level_result/tmp_part0.dta, replace
restore
* generate total number of observations by country 
preserve 
local conds = "(sic_n>6999 | sic_n<6000) & year>=1992 & year<=2011 & fic_code<."
sort gvkey_n datadate
duplicates drop gvkey_n year, force
by fic, sort: egen n_obs_total=count(fic_code) if `conds'
by fic, sort: egen min_year=min(year) if `conds'
by fic, sort: egen max_year=max(year) if `conds'
keep if n_obs_total<.
duplicates drop fic_code, force
keep fic fic_code fic_name region region_code min_year max_year n_obs_total
save ../firm_level_result/tmp_part1.dta, replace
restore
* generate numbr of observations with non-missing XLR
preserve
local conds = "(sic_n>6999 | sic_n<6000) & year>=1992 & year<=2011 & fic_code<."
sort gvkey_n datadate
duplicates drop gvkey_n year, force
by fic, sort: egen n_obs_xlr=count(fic_code) if `conds' & xlr<.
keep if n_obs_xlr<.
duplicates drop fic_code, force
keep fic fic_code n_obs_xlr
save ../firm_level_result/tmp_part2.dta, replace
restore
* generate numbr of observations with non-missing EDF
preserve
local conds = "(sic_n>6999 | sic_n<6000) & year>=1992 & year<=2011 & fic_code<."
sort gvkey_n datadate
duplicates drop gvkey_n year, force
by fic, sort: egen n_obs_edf=count(fic_code) if `conds' & avg_edf<.
keep if n_obs_edf<.
duplicates drop fic_code, force
keep fic fic_code n_obs_edf
save ../firm_level_result/tmp_part3.dta, replace
restore 
* generate numbr of observations with non-missing XLR and EDF
preserve
local conds = "(sic_n>6999 | sic_n<6000) & year>=1992 & year<=2011 & fic_code<."
sort gvkey_n datadate
duplicates drop gvkey_n year, force
by fic, sort: egen n_obs_xlr_edf=count(fic_code) if `conds' & xlr<. & avg_edf<. 
keep if n_obs_xlr_edf<.
duplicates drop fic_code, force
keep fic fic_code n_obs_xlr_edf
save ../firm_level_result/tmp_part4.dta, replace
restore
* put all 4 parts together
preserve
clear all
use ../firm_level_result/tmp_part1.dta
joinby fic using ../firm_level_result/tmp_part2.dta, unm(m)
tab _merge
drop _merge
joinby fic using ../firm_level_result/tmp_part3.dta, unm(m)
tab _merge
drop _merge
joinby fic using ../firm_level_result/tmp_part4.dta, unm(m)
tab _merge
drop _merge
sort region_code fic_code
append using ../firm_level_result/tmp_part0.dta
replace n_obs_xlr_edf=0 if n_obs_xlr_edf==.
gen fic_pct_xlr_edf=n_obs_xlr_edf/n_obs_total*100 if fic_name~="Total"
egen allfic_xlr_edf=sum(n_obs_xlr_edf) if fic_name~="Total"
gen allfic_pct_xlr_edf=n_obs_xlr_edf/allfic_xlr_edf*100 if fic_name~="Total"
format fic_pct_xlr_edf %9.2f
format allfic_pct_xlr_edf %9.2f
keep region fic_name min_year max_year n_obs_total n_obs_xlr n_obs_edf n_obs_xlr_edf fic_pct_xlr_edf allfic_pct_xlr_edf 
order region fic_name min_year max_year n_obs_total n_obs_xlr n_obs_edf n_obs_xlr_edf fic_pct_xlr_edf allfic_pct_xlr_edf 
label var region "Region"
label var fic_name "Country"
label var min_year "Start Year"
label var max_year "End Year"
label var n_obs_total "All Obs"
label var n_obs_xlr "# Obs w XLR"
label var n_obs_edf "# Obs w EDF"
label var n_obs_xlr_edf "# Obs XLR/EDF"
label var fic_pct_xlr_edf "Within Country % of obs w/ XLR/EDF"
label var allfic_pct_xlr_edf "For all countries % of obs w/ XLR/EDF"
save ../firm_level_result/OA_A8_summary_nonmissing_XLREDF.dta, replace
export excel ../firm_level_result/OA_A8_summary_nonmissing_XLREDF.xlsx, firstrow(varlabels) replace
restore
erase ../firm_level_result/tmp_part0.dta
erase ../firm_level_result/tmp_part1.dta
erase ../firm_level_result/tmp_part2.dta
erase ../firm_level_result/tmp_part3.dta
erase ../firm_level_result/tmp_part4.dta
*************** End of Online Table A8: No of Obs with non-missing XLR and EDF *********************


*************** Online Table A10 Summary Statistics on dxlr, lshr, edf *********************
*********** first calculate it for all countries
preserve 
sort gvkey datadate
gen lshr=xlr/(xlr+ebitda) if xlr>=0
gen LaborExpense=xlr*fx_acct if xlr>=0
gen d_xlr=2*(LaborExpense-LaborExpense[_n-1])/(LaborExpense+LaborExpense[_n-1]) if gvkey==gvkey[_n-1] & (fyear==fyear[_n-1]+1)

* deal with outliers
sort gvkey_n datadate
egen lshr_p99=pctile(lshr), p(99)
replace lshr=lshr_p99 if lshr>lshr_p99 & lshr<.
replace lshr=. if lshr<0

by fic, sort: egen dxlr_p1=pctile(d_xlr), p(1)
by fic, sort: egen dxlr_p99=pctile(d_xlr), p(99)
replace d_xlr=dxlr_p1 if d_xlr<dxlr_p1 
replace d_xlr=dxlr_p99 if d_xlr>dxlr_p99 & d_xlr<.

sort gvkey_n datadate
duplicates drop gvkey_n year, force

local conds = "(sic_n>6999 | sic_n<6000) & year>=1992 & year<=2011 & fic_code<."
egen mean_edf=mean(avg_edf) if `conds' 
egen mean_dxlr=mean(d_xlr) if `conds'
egen mean_lshr=mean(lshr) if `conds'
egen sd_edf=sd(avg_edf) if `conds'
egen sd_dxlr=sd(d_xlr) if `conds'
egen sd_lshr=sd(lshr) if `conds'
egen total_xlr=sum(LaborExpense) if `conds'
gen weight_xlr=LaborExpense/total_xlr if `conds'
egen vwmean_lshr=sum(weight_xlr*lshr) if `conds'
egen vwmean_dxlr=sum(weight_xlr*d_xlr) if `conds'
keep if mean_edf<. & mean_dxlr<. & mean_lshr<.
duplicates drop mean_edf, force
replace fic_name="Total"
replace fic=""
replace region=""
replace fic_code=.
replace region_code=.
keep region fic_name mean_edf sd_edf mean_dxlr vwmean_dxlr sd_dxlr mean_lshr vwmean_lshr sd_lshr
order region fic_name mean_edf sd_edf mean_dxlr vwmean_dxlr sd_dxlr mean_lshr vwmean_lshr sd_lshr
save ../firm_level_result/tmp_part0.dta, replace
restore

*********** then calculate it for each country
preserve
sort gvkey datadate
gen lshr=xlr/(xlr+ebitda) if xlr>=0
gen LaborExpense=xlr*fx_acct if xlr>=0
gen d_xlr=2*(LaborExpense-LaborExpense[_n-1])/(LaborExpense+LaborExpense[_n-1]) if gvkey==gvkey[_n-1] & (fyear==fyear[_n-1]+1)

* deal with outliers
sort gvkey_n datadate
egen lshr_p99=pctile(lshr), p(99)
replace lshr=lshr_p99 if lshr>lshr_p99 & lshr<.
replace lshr=. if lshr<0

by fic, sort: egen dxlr_p1=pctile(d_xlr), p(1)
by fic, sort: egen dxlr_p99=pctile(d_xlr), p(99)
replace d_xlr=dxlr_p1 if d_xlr<dxlr_p1 
replace d_xlr=dxlr_p99 if d_xlr>dxlr_p99 & d_xlr<.

sort gvkey_n datadate
duplicates drop gvkey_n year, force

local conds = "(sic_n>6999 | sic_n<6000) & year>=1992 & year<=2011 & fic_code<."
by fic, sort: egen mean_edf=mean(avg_edf) if `conds' 
by fic, sort: egen mean_dxlr=mean(d_xlr) if `conds'
by fic, sort: egen mean_lshr=mean(lshr) if `conds'  
by fic, sort: egen sd_edf=sd(avg_edf) if `conds'
by fic, sort: egen sd_dxlr=sd(d_xlr) if `conds'
by fic, sort: egen sd_lshr=sd(lshr) if `conds'
by fic, sort: egen total_xlr=sum(xlr) if `conds'
gen weight_xlr=xlr/total_xlr if `conds'
by fic, sort: egen vwmean_lshr=sum(weight_xlr*lshr) if `conds'
by fic, sort: egen vwmean_dxlr=sum(weight_xlr*d_xlr) if `conds'
keep if mean_edf<. & mean_dxlr<. & mean_lshr<.
duplicates drop fic_code, force
sort region_code fic_code
keep region fic_name mean_edf sd_edf mean_dxlr vwmean_dxlr sd_dxlr mean_lshr vwmean_lshr sd_lshr
order region fic_name mean_edf sd_edf mean_dxlr vwmean_dxlr sd_dxlr mean_lshr vwmean_lshr sd_lshr
append using ../firm_level_result/tmp_part0.dta

foreach var in mean_edf sd_edf mean_dxlr sd_dxlr mean_lshr sd_lshr {
format `var' %9.2f
}
label var region "Region"
label var fic_name "Country"
label var mean_edf "EDF Mean"
label var sd_edf "EDF St.D."
label var mean_dxlr "dXLR Mean"
label var vwmean_dxlr "dXLR Mean (VW)"
label var sd_dxlr "dXLR St.D."
label var mean_lshr "LS Mean"
label var vwmean_lshr "LS Mean (VW)"
label var sd_lshr "LS St.D."

save ../firm_level_result/OA_A10_summary_EDF_dXLR_LS.dta, replace
export excel ../firm_level_result/OA_A10_summary_EDF_dXLR_LS.xlsx, firstrow(varlabels) replace
restore
erase ../firm_level_result/tmp_part0.dta
*************** Online Table A10 Summary Statistics on dxlr, lshr, edf *********************


*************** Online Table A9 Summary Statistics on CDS sample *********************
clear all
set more off
use ../firm_level_data/working_data.dta
sort gvkey_n datadate
duplicates drop gvkey_n year, force
gen mu=1/dxlr_vol
joinby gvkey datadate using ../firm_level_data/ann_cds.dta, unm(m)
tab _merge
drop _merge
*** get the obs by year
preserve
local cond1= "year>=2000 & year<=2013 & fic_code<. & d_xlr<. & mu<. & lshr<."
keep if avg_cds5y_f1y<. &`cond1' & sigma<. & wc_ta<. & re_ta<. & ebit_ta<. & blev<. & SaleGr<. & ni_ta<. & ca_cl<. & invest<. & log_exr<. & rsize<. & log_rm<. & log_mcap<.
by year, sort: egen freq=count(year)
egen n_total_obs=count(year)
gen pct_obs=freq/n_total_obs*100
duplicates drop year, force
keep year freq pct_obs n_total_obs
order year freq pct_obs n_total_obs
label var year "Year"
label var freq "# Obs"
label var pct_obs "% Obs"
label var n_total_obs "Total"
export excel ../firm_level_result/OA_A9_summary_CDS_year.xlsx, firstrow(varlabels) replace
restore
*** get the obs by country
preserve
local cond1= "year>=2000 & year<=2013 & fic_code<. & d_xlr<. & mu<. & lshr<."
keep if avg_cds5y_f1y<. &`cond1' & sigma<. & wc_ta<. & re_ta<. & ebit_ta<. & blev<. & SaleGr<. & ni_ta<. & ca_cl<. & invest<. & log_exr<. & rsize<. & log_rm<. & log_mcap<.
by fic_code, sort: egen freq=count(year)
egen n_total_obs=count(year)
by fic_code, sort: egen mean_cds=mean(avg_cds5y_f1y)
by fic_code, sort: egen std_cds=sd(avg_cds5y_f1y)
gen pct_obs=freq/n_total_obs*100
duplicates drop fic_code, force
keep fic_code fic_name freq pct_obs mean_cds std_cds n_total_obs
order fic_code fic_name freq pct_obs mean_cds std_cds n_total_obs
label var fic_code "Country code"
label var fic_name "Country"
label var freq "# Obs"
label var pct_obs "% Obs"
label var n_total_obs "Total"
label var mean_cds "CDS Mean"
label var std_cds "CDS St.D."
keep if fic_code==4 | fic_code==5 | fic_code==6 | fic_code==8 | fic_code==9 | fic_code==13 | fic_code==14 | fic_code==15 | fic_code==16 | fic_code==17 | fic_code==18 | fic_code==20 | fic_code==22 | fic_code==23 | fic_code==25 | fic_code==33 | fic_code==39
save ../firm_level_result/OA_tab_summary_CDS_country_part1.dta, replace
restore
** full sample mean and std of CDS
preserve
local cond1= "year>=2000 & year<=2013 & fic_code<. & d_xlr<. & mu<. & lshr<."
keep if avg_cds5y_f1y<. &`cond1' & sigma<. & wc_ta<. & re_ta<. & ebit_ta<. & blev<. & SaleGr<. & ni_ta<. & ca_cl<. & invest<. & log_exr<. & rsize<. & log_rm<. & log_mcap<.
egen mean_cds=mean(avg_cds5y_f1y)
egen std_cds=sd(avg_cds5y_f1y)
egen freq=count(year)
egen n_total_obs=count(year)
gen pct_obs=freq/n_total_obs*100
duplicates drop n_total_obs, force
replace fic_code=.
replace fic_name="Total"
keep fic_code fic_name freq pct_obs mean_cds std_cds n_total_obs
order fic_code fic_name freq pct_obs mean_cds std_cds n_total_obs
label var freq "# Obs"
label var pct_obs "% Obs"
label var n_total_obs "Total"
label var mean_cds "CDS Mean"
label var std_cds "CDS St.D."
save ../firm_level_result/OA_tab_summary_CDS_country_part2.dta, replace
restore
** Other countries mean and std of CDS
preserve
local cond1= "year>=2000 & year<=2013 & fic_code<. & d_xlr<. & mu<. & lshr<."
keep if avg_cds5y_f1y<. &`cond1' & sigma<. & wc_ta<. & re_ta<. & ebit_ta<. & blev<. & SaleGr<. & ni_ta<. & ca_cl<. & invest<. & log_exr<. & rsize<. & log_rm<. & log_mcap<.
egen n_total_obs=count(year)
keep if fic_code~=4 & fic_code~=5 & fic_code~=6 & fic_code~=8 & fic_code~=9 & fic_code~=13 & fic_code~=14 & fic_code~=15 & fic_code~=16 & fic_code~=17 & fic_code~=18 & fic_code~=20 & fic_code~=22 & fic_code~=23 & fic_code~=25 & fic_code~=33 & fic_code~=39
egen mean_cds=mean(avg_cds5y_f1y)
egen std_cds=sd(avg_cds5y_f1y)
egen freq=count(year)
gen pct_obs=freq/n_total_obs*100
duplicates drop n_total_obs, force
replace fic_code=.
replace fic_name="Other"
keep fic_code fic_name freq pct_obs mean_cds std_cds n_total_obs
order fic_code fic_name freq pct_obs mean_cds std_cds n_total_obs
label var freq "# Obs"
label var pct_obs "% Obs"
label var n_total_obs "Total"
label var mean_cds "CDS Mean"
label var std_cds "CDS St.D."
save ../firm_level_result/OA_tab_summary_CDS_country_part3.dta, replace
restore
preserve
clear all
use ../firm_level_result/OA_tab_summary_CDS_country_part1.dta
append using ../firm_level_result/OA_tab_summary_CDS_country_part3.dta
append using ../firm_level_result/OA_tab_summary_CDS_country_part2.dta
save ../firm_level_result/OA_A9_summary_CDS_country.dta, replace
export excel ../firm_level_result/OA_A9_summary_CDS_country.xlsx, firstrow(varlabels) replace
restore
capture erase ../firm_level_result/OA_tab_summary_CDS_country_part1.dta
capture erase ../firm_level_result/OA_tab_summary_CDS_country_part2.dta
capture erase ../firm_level_result/OA_tab_summary_CDS_country_part3.dta

*************** End of Online Table A9 Summary Statistics on CDS sample *********************


*************** Online Tables A19 and A20 Summary Statistics on firm-level time-series correlations *********************
clear all
set more off
use ../firm_level_data/working_data.dta
duplicates drop gvkey, force
keep gvkey_n fic fic_code fic_name region region_code sic_n
rename gvkey_n col1
joinby col1 using ../firm_level_result/DXlrLshrEDFDebt.dta, unm(m)
drop _merge
rename col1 gvkey_n 
rename col2 corrdxe
rename col3 corrlse
rename col4 corrdxd
rename col5 corrlsd
local conds = "(sic_n>6999 | sic_n<6000) & fic_code<."

* get summary stats on corr(dXLR, EDF), corr(LS, EDF)
preserve
by fic, sort: egen mean_corrdxe=mean(corrdxe) if `conds' 
by fic, sort: egen sd_corrdxe=sd(corrdxe) if `conds'
by fic, sort: egen n_corrdxe=count(corrdxe) if `conds'
gen SE_corrdxe=sd_corrdxe/sqrt(n_corrdxe)
by fic, sort: egen mean_corrlse=mean(corrlse) if `conds' 
by fic, sort: egen sd_corrlse=sd(corrlse) if `conds'
by fic, sort: egen n_corrlse=count(corrlse) if `conds'
gen SE_corrlse=sd_corrlse/sqrt(n_corrlse) 
keep if mean_corrdxe<. & mean_corrlse<. 
duplicates drop fic_code, force
sort region_code fic_code
keep region fic_name mean_corrdxe sd_corrdxe n_corrdxe SE_corrdxe mean_corrlse sd_corrlse n_corrlse SE_corrlse
order region fic_name mean_corrdxe sd_corrdxe n_corrdxe SE_corrdxe mean_corrlse sd_corrlse n_corrlse SE_corrlse
label var region "Region"
label var fic_name "Country"
label var mean_corrdxe "Mean Corr(dXLR, EDF)"
label var sd_corrdxe "St.D. Corr(dXLR, EDF)"
label var n_corrdxe "No of firms"
label var SE_corrdxe "St.E. Corr(dXLR, EDF)=0"
label var mean_corrlse "Mean Corr(LS, EDF)"
label var sd_corrlse "St.D. Corr(LS, EDF)"
label var n_corrlse "No of firms"
label var SE_corrlse "St.E. Corr(LS, EDF)=0"
save ../firm_level_result/tmp1.dta, replace
restore
preserve
egen mean_corrdxe=mean(corrdxe) if `conds' 
egen sd_corrdxe=sd(corrdxe) if `conds'
egen n_corrdxe=count(corrdxe) if `conds'
gen SE_corrdxe=sd_corrdxe/sqrt(n_corrdxe)
egen mean_corrlse=mean(corrlse) if `conds' 
egen sd_corrlse=sd(corrlse) if `conds'
egen n_corrlse=count(corrlse) if `conds'
gen SE_corrlse=sd_corrlse/sqrt(n_corrlse) 
keep if mean_corrdxe<. & mean_corrlse<. 
duplicates drop n_corrdxe, force
replace fic_name="Total"
replace region=""
keep region fic_name mean_corrdxe sd_corrdxe n_corrdxe SE_corrdxe mean_corrlse sd_corrlse n_corrlse SE_corrlse
order region fic_name mean_corrdxe sd_corrdxe n_corrdxe SE_corrdxe mean_corrlse sd_corrlse n_corrlse SE_corrlse
save ../firm_level_result/tmp2.dta, replace
restore
preserve
clear all
use ../firm_level_result/tmp1.dta
append using ../firm_level_result/tmp2.dta
save ../firm_level_result/OA_A19_summary_corr_EDF.dta, replace
export excel ../firm_level_result/OA_A19_summary_corr_EDF.xlsx, firstrow(varlabels) replace
restore

capture erase ../firm_level_result/tmp1.dta
capture erase ../firm_level_result/tmp2.dta


* get summary stats on corr(dXLR, DebtGr), corr(LS, DebtGr)
preserve
by fic, sort: egen mean_corrdxd=mean(corrdxd) if `conds' 
by fic, sort: egen sd_corrdxd=sd(corrdxd) if `conds'
by fic, sort: egen n_corrdxd=count(corrdxd) if `conds'
gen SE_corrdxd=sd_corrdxd/sqrt(n_corrdxd)
by fic, sort: egen mean_corrlsd=mean(corrlsd) if `conds' 
by fic, sort: egen sd_corrlsd=sd(corrlsd) if `conds'
by fic, sort: egen n_corrlsd=count(corrlsd) if `conds'
gen SE_corrlsd=sd_corrlsd/sqrt(n_corrlsd) 
keep if mean_corrdxd<. & mean_corrlsd<. 
duplicates drop fic_code, force
sort region_code fic_code
keep region fic_name mean_corrdxd sd_corrdxd n_corrdxd SE_corrdxd mean_corrlsd sd_corrlsd n_corrlsd SE_corrlsd
order region fic_name mean_corrdxd sd_corrdxd n_corrdxd SE_corrdxd mean_corrlsd sd_corrlsd n_corrlsd SE_corrlsd
label var region "Region"
label var fic_name "Country"
label var mean_corrdxd "Mean Corr(dXLR, DebtGr)"
label var sd_corrdxd "St.D. Corr(dXLR, DebtGr)"
label var n_corrdxd "No of firms"
label var SE_corrdxd "St.E. Corr(dXLR, EDF)=0"
label var mean_corrlsd "Mean Corr(LS, EDF)"
label var sd_corrlsd "St.D. Corr(LS, EDF)"
label var n_corrlsd "No of firms"
label var SE_corrlsd "St.E. Corr(LS, EDF)=0"
save ../firm_level_result/tmp1.dta, replace
restore
preserve
egen mean_corrdxd=mean(corrdxd) if `conds' 
egen sd_corrdxd=sd(corrdxd) if `conds'
egen n_corrdxd=count(corrdxd) if `conds'
gen SE_corrdxd=sd_corrdxd/sqrt(n_corrdxd)
egen mean_corrlsd=mean(corrlsd) if `conds' 
egen sd_corrlsd=sd(corrlsd) if `conds'
egen n_corrlsd=count(corrlsd) if `conds'
gen SE_corrlsd=sd_corrlsd/sqrt(n_corrlsd) 
keep if mean_corrdxd<. & mean_corrlsd<. 
duplicates drop n_corrdxd, force
replace fic_name="Total"
replace region=""
keep region fic_name mean_corrdxd sd_corrdxd n_corrdxd SE_corrdxd mean_corrlsd sd_corrlsd n_corrlsd SE_corrlsd
order region fic_name mean_corrdxd sd_corrdxd n_corrdxd SE_corrdxd mean_corrlsd sd_corrlsd n_corrlsd SE_corrlsd
save ../firm_level_result/tmp2.dta, replace
restore
preserve
clear all
use ../firm_level_result/tmp1.dta
append using ../firm_level_result/tmp2.dta
save ../firm_level_result/OA_A20_summary_corr_DebtGr.dta, replace
export excel ../firm_level_result/OA_A20_summary_corr_DebtGr.xlsx, firstrow(varlabels) replace
restore

capture erase ../firm_level_result/tmp1.dta
capture erase ../firm_level_result/tmp2.dta

