/* need to change the directory to your own directory*/
libname mylocal 'J:\CG Security Daily';

/* 
cg_price1990: from Compustat Global Security Daily file (only keep 1990 as the file is too big)
it includes the following key data items:
gvkey, iid, datadate, cshoc, prccd, fic, ajexdi, tfrd, tpci, prirow
*/
data cg_price;
    set mylocal.cg_price1990on;
run;


/* follow Gao, Parsons, and Shen 2014 to deal with the price data */
/******* keep the main issue of each company *******/
data cg_price;
    set cg_price;
    where iid=prirow;
run;
/******* keep only common stocks *******/
data cg_price;
    set cg_price;
    where tpci="0";
run;
/* 
cg_endofmonth: from Compustat Global Security Daily file.
key data items: gvkey, iid, datadate, monthend
*/
data cg_endofmonth;
    set mylocal.cg_endofmonth;
    where monthend=1;
run;
proc sql;
    create table cg_price as
    select a.*, b.monthend
    from cg_price as a left join cg_endofmonth as b
    on a.gvkey=b.gvkey and a.datadate=b.datadate and a.iid=b.iid;
quit;
/* generate monthly files to keep the data size more manageable */
data cg_price_m;
    set cg_price;
    where monthend=1;
run;
data cg_price_m;
    set cg_price_m;
    year=year(datadate);
    month=month(datadate);
    mcap=cshoc*prccd;
    prcc_adj=prccd/ajexdi;
run;
data cg_price;
    set cg_price;
    where fic~="";
run;
data cg_price_m;
    set cg_price_m;
    where fic~="";
run;

proc sort data=cg_price_m;
    by fic year month;
run;

proc univariate noprint data=cg_price_m;
     by fic year month;
     var prcc_adj;
     output out=price_pct5 pctlpts=5 pctlpre=price_pct;
run;

proc univariate noprint data=cg_price_m;
     by fic year month;
     var mcap;
     output out=mcap_pct5 pctlpts=5 pctlpre=mcap_pct;
run;
/* generate price standard deviation witin a month */
proc sql;
    create table price_std as
    select distinct a.gvkey, a.iid, year(a.datadate) as year, month(a.datadate) as month, std(prccd) as price_std
    from cg_price as a 
    group by a.gvkey, a.iid, year(a.datadate), month(a.datadate);
quit;

data price_std;
    set price_std;
    if missing(price_std) then price_std=0;
run;
proc sql;
    create table cg_price_m as
    select a.*, b.price_pct5
    from cg_price_m as a left join price_pct5 as b
    on a.fic=b.fic and year(a.datadate)=b.year and month(a.datadate)=b.month;
quit;
proc sql;
    create table cg_price_m as
    select a.*, b.mcap_pct5
    from cg_price_m as a left join mcap_pct5 as b
    on a.fic=b.fic and year(a.datadate)=b.year and month(a.datadate)=b.month;
quit;

proc sql;
    create table cg_price_m as
    select a.*, b.price_std
    from cg_price_m as a left join price_std as b
    on a.gvkey=b.gvkey and a.iid=b.iid and year(a.datadate)=b.year and month(a.datadate)=b.month;
quit;


/* 
cg_currencycode: from Compustat Global Security Daily file.
key data items: gvkey, datadate, isin, sedol, curcdd
*/
data cg_currency;
    set mylocal.cg_currencycode;
run;

proc sql;
    create table cg_price_m as
    select a.*, b.isin, b.sedol, b.curcdd
    from cg_price_m as a left join cg_currency as b
    on a.gvkey=b.gvkey and a.iid=b.iid and (a.datadate)=b.datadate;
quit;

/* 
ws_id_linktbl_nondup: from worldscope.
key data items: worldscopeID, isin, sedol
*/
data ws_id_linktbl;
    set mylocal.ws_id_linktbl_nondup;
run;

proc sql;
    create table cg_price_m as
    select a.*, b.WorldscopeID
    from cg_price_m as a left join ws_id_linktbl as b
    on a.isin=b.isin and b.isin~="";
quit;

proc sql;
    create table cg_price_m as
    select a.*, b.WorldscopeID as WorldscopeID_1
    from cg_price_m as a left join ws_id_linktbl as b
    on a.sedol=b.sedol and b.sedol~="" and a.isin="";
quit;

data cg_price_m;
    set cg_price_m;
    if missing(WorldscopeID) then WorldscopeID=WorldscopeID_1;
    gvkey_n=gvkey*1;
run;

data cg_price_m;
    set cg_price_m;
    drop WorldscopeID_1;
run;

/* 
edf_update: from Moody's. This is a monthly file. 
we use Moody's proprietary information to geneate common IDs to link to Compustat datasets
*/
data edf;
    set mylocal.edf_update;
run;

proc sql;
    create table cg_price_m as
    select a.*, b.edf 
    from cg_price_m as a left join edf as b
    on a.gvkey_n=b.gvkey_n and (not missing(b.gvkey_n)) and a.year=b.year and a.month=b.month;
quit;

proc sql;
    create table cg_price_m as
    select a.*, b.edf as edf_1
    from cg_price_m as a left join edf as b
    on a.WorldscopeID=b.WorldscopeID and (not missing(b.WorldscopeID)) and a.year=b.year and a.month=b.month;
quit;

data cg_price_m;
    set cg_price_m;
    if missing(edf) then edf=edf_1;
run;

data cg_price_m;
    set cg_price_m;
    drop edf_1;
run;

data mylocal.cg_price_m_5f_edf;
    set cg_price_m;
run;
