/* need to change the directory to your own directory*/
libname mylocal 'J:\CG Security Daily';

/* keep USA and CANADA from the compustat north america security daily */
/* 
cna_sd: from Compustat North America Security Daily file (similar to cg_price1990on)
key items: gvkey, iid, datadate, prican, prirow, priusa, exchg, fic, tpci
           ajexdi, cshoc, curcdd, prccd, trfd
*/
data cg_price;
    set mylocal.cna_sd;
    where fic="CAN" or fic="USA";
run;

/******* keep the main issue of each company on major exchanges *******/
/** 7 - tsx; 8 - montreal; 10 - alberta; 11 - nyse; 12 - amx ; 14 - nasdaq **/
 
data cg_price;
    set cg_price;
    where exchg=7 or exchg=8 or exchg=10 or exchg=11 or exchg=12 or exchg=14;
    where (iid=priusa and fic="USA") or (iid=prican and fic="CAN");
run;

/******* keep only common stocks *******/
data cg_price;
    set cg_price;
    where tpci="0";
run;

proc sql;
    create table cna_monthend as
    select distinct gvkey, iid, max(datadate) as monthend
    from cg_price 
    group by gvkey, iid, year(datadate), month(datadate);
quit;
/* keep month file */
proc sql;
    create table cg_price_m as
    select b.*
    from cna_monthend as a left join cg_price as b
    on a.gvkey=b.gvkey and a.iid=b.iid and a.monthend=b.datadate;
quit;

data cg_price_m;
    set cg_price_m;
    year=year(datadate);
    month=month(datadate);
    mcap=cshoc*prccd;
    prcc_adj=prccd/ajexdi;
run;

proc sort data=cg_price_m;
    by fic year month;
run;

proc univariate noprint data=cg_price_m;
     by fic year month;
     var prcc_adj;
     output out=price_pct5 pctlpts=5 pctlpre=price_pct;
run;

proc univariate noprint data=cg_price_m;
     by fic year month;
     var mcap;
     output out=mcap_pct5 pctlpts=5 pctlpre=mcap_pct;
run;

proc sql;
    create table price_std as
    select distinct a.gvkey, a.iid, year(a.datadate) as year, month(a.datadate) as month, std(prccd) as price_std
    from cg_price as a 
    group by a.gvkey, a.iid, year(a.datadate), month(a.datadate);
quit;

data price_std;
    set price_std;
    if missing(price_std) then price_std=0;
run;

proc sql;
    create table cg_price_m as
    select a.*, b.price_pct5
    from cg_price_m as a left join price_pct5 as b
    on a.fic=b.fic and year(a.datadate)=b.year and month(a.datadate)=b.month;
quit;

data cg_price_m;
    set cg_price_m;
    if fic="USA" then price_pct5=5;
run;

proc sql;
    create table cg_price_m as
    select a.*, b.mcap_pct5
    from cg_price_m as a left join mcap_pct5 as b
    on a.fic=b.fic and year(a.datadate)=b.year and month(a.datadate)=b.month;
quit;

proc sql;
    create table cg_price_m as
    select a.*, b.price_std
    from cg_price_m as a left join price_std as b
    on a.gvkey=b.gvkey and a.iid=b.iid and year(a.datadate)=b.year and month(a.datadate)=b.month;
quit;

data cg_price_m;
    set cg_price_m;
    gvkey_n=gvkey*1;
run;

data edf;
    set mylocal.edf_update;
run;

proc sql;
    create table cg_price_m as
    select a.*, b.edf 
    from cg_price_m as a left join edf as b
    on a.gvkey_n=b.gvkey_n and (not missing(b.gvkey_n)) and a.year=b.year and a.month=b.month;
quit;

data mylocal.cna_price_m_5f_edf;
    set cg_price_m;
run;


/**** now we merge CG and CNA price data together ****/

data cg_price_m;
    set mylocal.cna_price_m_5f_edf mylocal.cg_price_m_5f_edf;
run;

data cg_price_m;
    set cg_price_m;
    drop prican prirow priusa exchg cshtrd divd monthend isin sedol worldscopeid tpci;
    where price_std>0 and prcc_adj>=price_pct5 and mcap>=mcap_pct5;
run;

data cg_price_m;
    set cg_price_m;
    yearmonth=year*100+month;
    where not missing(edf);
run;

proc sql;
    create table no_stocks as
    select distinct fic, yearmonth, count(gvkey_n) as n_stocks
    from cg_price_m 
    group by fic, yearmonth;
quit;

proc sql;
    create table no_months as
    select distinct fic, count(yearmonth) as n_months
    from cg_price_m 
    group by fic;
quit;

proc sql;
    create table cg_price_m as
    select a.*, b.n_stocks
    from cg_price_m as a left join no_stocks as b
    on a.fic=b.fic and a.yearmonth=b.yearmonth;
quit;

proc sql;
    create table cg_price_m as
    select a.*, b.n_months
    from cg_price_m as a left join no_months as b
    on a.fic=b.fic;
quit;

data cg_price_m;
    set cg_price_m;
    where fic not in ("BMU","CYM","CZE","EGY","IRL");
run;

data mylocal.cg_final;
    set cg_price_m;
run;
