**********************************************
* Beg: Merge datasets
**********************************************
clear all
set more off
use ../firm_level_data/def_data.dta
joinby gvkey datadate using ../firm_level_data/cg_cna_sale.dta, unm(m)
drop _merge
joinby gvkey datadate using ../firm_level_data/cg_cna_defvar.dta, unm(m)
drop _merge
joinby fic using ../firm_level_data/FIC_code, unm(m)
drop _merge
joinby gvkey datadate using ../firm_level_data/fx_acct.dta, unm(m)
drop _merge
joinby gvkey datadate using ../firm_level_data/cgcna_update.dta, unm(m)
drop _merge
joinby gvkey datadate using ../firm_level_data/cg_cna_ebitda.dta, unm(m)
drop _merge
joinby gvkey datadate using ../firm_level_data/cg_cna_xint.dta, unm(m)
drop _merge
joinby gvkey datadate using ../firm_level_data/def_data_201503.dta, unm(m)
drop _merge
/**********************************************
* End: Merge datasets
**********************************************/

**********************************************
* Beg: Create varibles for regressions
**********************************************
gen year=year(datadate)
gen sic_n=real(sic)
sort gvkey datadate
* RHS accounting variables. 
* Note: the return based RHS variables are constructed in the SAS code
gen wc_ta=wcap/at if at>0
gen re_ta=re/at if at>0
gen ebit_ta=ebit/at if at>0 
gen s_ta=sale/at if at>0
gen ni_ta=nicon/at if at>0
gen ca_cl=act/lct
gen invest=capx/ppent[_n-1] if gvkey==gvkey[_n-1]
gen log_mcap=log(mcap)

******* key variables of interest *********
* negative labor expenses are likely data errors 
* lshr: labor share
gen lshr=xlr/(xlr+ebitda) if xlr>=0
* for growth variables, we first make sure the level variables
* are in the same currency (sometimes firms change reporting currency from year to year)
* then we calculate the growth rates
gen Debt=(dltt+dlc)*fx_acct if dltt>=0 & dlc>=0 
gen LaborExpense=xlr*fx_acct if xlr>=0
gen Sale=sale*fx_acct if sale>=0
gen SaleGr=2*(Sale-Sale[_n-1])/(Sale+Sale[_n-1]) if gvkey==gvkey[_n-1] & (fyear==fyear[_n-1]+1)
* key growth variables: 
* d_xlr: labor expenses growth rate
* DebtGr: debt growth rate
gen d_xlr=2*(LaborExpense-LaborExpense[_n-1])/(LaborExpense+LaborExpense[_n-1]) if gvkey==gvkey[_n-1] & (fyear==fyear[_n-1]+1)
gen DebtGr=2*(Debt-Debt[_n-1])/(Debt+Debt[_n-1]) if gvkey==gvkey[_n-1] & (fyear==fyear[_n-1]+1) & Debt>0 & Debt[_n-1]>0
* create EDF and DebtGr in year t+1, to be used as LHS variables later
gen avg_edf_f1y=avg_edf[_n+1] if gvkey==gvkey[_n+1] & (fyear==fyear[_n+1]-1)
gen DebtGr_f1y=DebtGr[_n+1] if gvkey==gvkey[_n+1] & (fyear==fyear[_n+1]-1)
* HN and WageGr for robustness results in the online appendix
gen HN=2*(emp-emp[_n-1])/(emp+emp[_n-1]) if gvkey==gvkey[_n-1] & (fyear==fyear[_n-1]+1)
gen Wage=LaborExpense/emp
gen WageGr=2*(Wage-Wage[_n-1])/(Wage+Wage[_n-1]) if gvkey==gvkey[_n-1] & (fyear==fyear[_n-1]+1) 
* generate volatility of labor expenses growth rate
by gvkey, sort: egen dxlr_vol=sd(d_xlr)

************************ deal with outliers in control variables **************************
foreach var in wc_ta re_ta ebit_ta s_ta ni_ta ca_cl invest sigma log_exr rsize log_rm log_mcap{
   qui by fic, sort: egen `var'_p1=pctile(`var'), p(1)
   qui by fic, sort: egen `var'_p99=pctile(`var'), p(99)
   qui replace `var'=`var'_p1 if `var'<`var'_p1
   qui replace `var'=`var'_p99 if `var'>`var'_p99
}
* generate country dummies for the country fixed effects
* fic_code is our country code
xi i.fic_code
rename _Ific_code* Ific_code*
save ../firm_level_data/working_data.dta, replace
